@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 extensions = ['sphinx.ext.autodoc', 'jaraco.packaging.sphinx', 'rst.linker']
 
@@ -19,7 +18,11 @@ link_files = {
             ),
             dict(
                 pattern=r'PEP[- ](?P<pep_number>\d+)',
-                url='https://www.python.org/dev/peps/pep-{pep_number:0>4}/',
+                url='https://peps.python.org/pep-{pep_number:0>4}/',
+            ),
+            dict(
+                pattern=r'(Python #|py-)(?P<python>\d+)',
+                url='https://github.com/python/cpython/issues/{python}',
             ),
         ],
     )
@@ -28,17 +31,19 @@ link_files = {
 # Be strict about any broken references:
 nitpicky = True
 
-# Support intersphinx links
-extensions += [
-    'sphinx.ext.intersphinx',
-]
+# Include Python intersphinx mapping to prevent failures
+# jaraco/skeleton#51
+extensions += ['sphinx.ext.intersphinx']
 intersphinx_mapping = {
     'python': ('https://docs.python.org/3', None),
-    'importlib_resources': (
+}
+
+intersphinx_mapping.update(
+    importlib_resources=(
         'https://importlib-resources.readthedocs.io/en/latest/',
         None,
     ),
-}
+)
 
 # Workaround for #316
 nitpick_ignore = [
